<?php $TRANSLATIONS = array(
"Music" => "Musica",
"songs" => "brani",
"albums" => "album",
"Add album to playlist" => "Aggiungi album alla scaletta",
"Play" => "Riproduci",
"Pause" => "Pausa",
"Previous" => "Precedente",
"Next" => "Successivo",
"Mute" => "Disattiva audio",
"Unmute" => "Riattiva audio",
"Rescan Collection" => "Nuova scansione collezione",
"Artist" => "Artista",
"Album" => "Album",
"Title" => "Titolo"
);
